#[non_exhaustive]pub enum CompressAlgorithm {
Brotli(BrotliAlgorithm),
Lz4,
Snappy,
Zstd(ZstdCompressionLevel),
Unknown(u8),
}Available on crate features
zstd or lz4 or brotli or snappy only.Expand description
The compressioned algorithm used to compression the message.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Brotli(BrotliAlgorithm)
Available on crate feature
brotli only.Brotli
Lz4
Available on crate feature
lz4 only.LZ4
Snappy
Available on crate feature
snappy only.Snappy
Zstd(ZstdCompressionLevel)
Available on crate feature
zstd only.Zstd
Unknown(u8)
Unknwon compressioned algorithm
Implementations
Sourceimpl CompressAlgorithm
impl CompressAlgorithm
Sourcepub const fn is_brotli(&self) -> bool
pub const fn is_brotli(&self) -> bool
Returns true if this value is of type Brotli. Returns false otherwise
Sourcepub const fn is_lz_4(&self) -> bool
pub const fn is_lz_4(&self) -> bool
Returns true if this value is of type Lz4. Returns false otherwise
Sourcepub const fn is_snappy(&self) -> bool
pub const fn is_snappy(&self) -> bool
Returns true if this value is of type Snappy. Returns false otherwise
Sourcepub const fn is_zstd(&self) -> bool
pub const fn is_zstd(&self) -> bool
Returns true if this value is of type Zstd. Returns false otherwise
Sourcepub const fn is_unknown(&self) -> bool
pub const fn is_unknown(&self) -> bool
Returns true if this value is of type Unknown. Returns false otherwise
Sourceimpl CompressAlgorithm
impl CompressAlgorithm
Sourcepub fn decompress_to(
&self,
src: &[u8],
dst: &mut [u8],
) -> Result<usize, CompressionError>
pub fn decompress_to( &self, src: &[u8], dst: &mut [u8], ) -> Result<usize, CompressionError>
Decompresses the given buffer.
Sourcepub fn max_compress_len(
&self,
input_size: usize,
) -> Result<usize, CompressionError>
pub fn max_compress_len( &self, input_size: usize, ) -> Result<usize, CompressionError>
Returns the maximum compressed length of the given buffer.
This is useful when you want to pre-allocate the buffer before compressing.
Sourcepub fn compress_to(
&self,
src: &[u8],
dst: &mut [u8],
) -> Result<usize, CompressionError>
pub fn compress_to( &self, src: &[u8], dst: &mut [u8], ) -> Result<usize, CompressionError>
Compresses the given buffer.
The dst buffer should be pre-allocated with the max_compress_len method.