pub struct TupleEncoder<'a, A, B> { /* private fields */ }Expand description
The encoder for a tuple of two data types.
Implementations
Sourceimpl<'a, A, B> TupleEncoder<'a, A, B>
impl<'a, A, B> TupleEncoder<'a, A, B>
Sourceimpl<A, B> TupleEncoder<'_, A, B>
impl<A, B> TupleEncoder<'_, A, B>
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the data only considering the data itself, (e.g. no length prefix, no wire type).
Sourcepub fn encoded_len_with_length_delimited(&self) -> usize
pub fn encoded_len_with_length_delimited(&self) -> usize
Returns the encoded length of the data including the length delimited.
Sourcepub fn encode(&self, buf: &mut [u8]) -> Result<usize, EncodeError>
pub fn encode(&self, buf: &mut [u8]) -> Result<usize, EncodeError>
Encodes the message to a buffer.
An error will be returned if the buffer does not have sufficient capacity.
Sourcepub fn encode_with_length_delimited(
&self,
buf: &mut [u8],
) -> Result<usize, EncodeError>
pub fn encode_with_length_delimited( &self, buf: &mut [u8], ) -> Result<usize, EncodeError>
Encodes the message with a length-delimiter to a buffer.
An error will be returned if the buffer does not have sufficient capacity.