pub enum DecodeError {
BufferUnderflow,
MissingField {
ty: &'static str,
field: &'static str,
},
DuplicateField {
ty: &'static str,
field: &'static str,
tag: u8,
},
UnknownWireType {
ty: &'static str,
value: u8,
tag: u8,
},
UnknownTag {
ty: &'static str,
tag: u8,
},
LengthDelimitedOverflow,
Custom(Cow<'static, str>),
}Expand description
A message decoding error.
DecodeError indicates that the input buffer does not contain a valid
message. The error details should be considered ‘best effort’: in
general it is not possible to exactly pinpoint why data is malformed.
Variants
BufferUnderflow
Returned when the buffer does not have enough data to decode the message.
MissingField
Returned when the buffer does not contain the required field.
DuplicateField
Returned when the buffer contains duplicate fields for the same tag in a message.
Fields
UnknownWireType
Returned when there is a unknown wire type.
Fields
UnknownTag
Returned when finding a unknown tag.
LengthDelimitedOverflow
Returned when fail to decode the length-delimited
Custom(Cow<'static, str>)
A custom decoding error.
Implementations
Sourceimpl DecodeError
impl DecodeError
Sourcepub const fn is_buffer_underflow(&self) -> bool
pub const fn is_buffer_underflow(&self) -> bool
Returns true if this value is of type BufferUnderflow. Returns false otherwise
Sourcepub const fn is_missing_field(&self) -> bool
pub const fn is_missing_field(&self) -> bool
Returns true if this value is of type MissingField. Returns false otherwise
Sourcepub const fn is_duplicate_field(&self) -> bool
pub const fn is_duplicate_field(&self) -> bool
Returns true if this value is of type DuplicateField. Returns false otherwise
Sourcepub const fn is_unknown_wire_type(&self) -> bool
pub const fn is_unknown_wire_type(&self) -> bool
Returns true if this value is of type UnknownWireType. Returns false otherwise
Sourcepub const fn is_unknown_tag(&self) -> bool
pub const fn is_unknown_tag(&self) -> bool
Returns true if this value is of type UnknownTag. Returns false otherwise
Sourcepub const fn is_length_delimited_overflow(&self) -> bool
pub const fn is_length_delimited_overflow(&self) -> bool
Returns true if this value is of type LengthDelimitedOverflow. Returns false otherwise
Sourceimpl DecodeError
impl DecodeError
Sourcepub const fn buffer_underflow() -> Self
pub const fn buffer_underflow() -> Self
Creates a new buffer underflow decoding error.
Sourcepub const fn missing_field(ty: &'static str, field: &'static str) -> Self
pub const fn missing_field(ty: &'static str, field: &'static str) -> Self
Creates a new missing field decoding error.
Sourcepub const fn duplicate_field(
ty: &'static str,
field: &'static str,
tag: u8,
) -> Self
pub const fn duplicate_field( ty: &'static str, field: &'static str, tag: u8, ) -> Self
Creates a new duplicate field decoding error.
Sourcepub const fn unknown_wire_type(ty: &'static str, value: u8, tag: u8) -> Self
pub const fn unknown_wire_type(ty: &'static str, value: u8, tag: u8) -> Self
Creates a new unknown wire type decoding error.
Sourcepub const fn unknown_tag(ty: &'static str, tag: u8) -> Self
pub const fn unknown_tag(ty: &'static str, tag: u8) -> Self
Creates a new unknown tag decoding error.